@@ -10,13 +10,12 @@ or GCHP benchmark simulations.
 import os
 import warnings
 from calendar import monthrange
-import yaml
 import numpy as np
 import xarray as xr
-from yaml import load as yaml_load_file
 import gcpy.constants as constants
 from gcpy.grid import get_troposphere_mask
 import gcpy.util as util
+import gc
 
 # Suppress harmless run-time warnings (mostly about underflow in division)
 warnings.filterwarnings("ignore", category=RuntimeWarning)
@@ -38,9 +37,11 @@ class _GlobVars:
             devrstdir,
             year,
             dst,
-            is_gchp,
             overwrite,
-            spcdb_dir
+            spcdb_dir,
+            is_gchp,
+            gchp_res,
+            gchp_is_pre_14_0
     ):
         """
         Initializes the _GlobVars class.
@@ -56,12 +57,17 @@ class _GlobVars:
                 Directory where plots & tables will be created.
             year: int
                 Year of the benchmark simulation.
-            is_gchp: bool
-                Denotes if this is GCHP (True) or GCC (False) data.
             overwrite: bool
                 Denotes whether to ovewrite existing budget tables.
             spcdb_dir: str
                 Directory where species_database.yml is stored.
+            is_gchp: bool
+                Denotes if this is GCHP (True) or GCC (False) data.
+            gchp_res: str
+                GCHP resolution string (e.g. "c24", "c48", etc.)
+            gchp_is_pre_14_0: bool
+                Denotes if the GCHP version is prior to 14.0.0 (True)
+                or not (False).
         """
         # --------------------------------------------------------------
         # Arguments from outside
@@ -70,11 +76,13 @@ class _GlobVars:
         self.devdir = devdir
         self.devrstdir = devrstdir
         self.dst = dst
-        self.is_gchp = is_gchp
         self.overwrite = overwrite
         if spcdb_dir is None:
             spcdb_dir = os.path.dirname(__file__)
         self.spcdb_dir = spcdb_dir
+        self.is_gchp = is_gchp
+        self.gchp_res = gchp_res
+        self.gchp_is_pre_14_0 = gchp_is_pre_14_0
 
         # ---------------------------------------------------------------
         # Benchmark year
@@ -132,13 +140,13 @@ class _GlobVars:
         # First look in the current folder
         lspc_path = "lumped_species.yml"
         if os.path.exists(lspc_path):
-            lspc_dict = yaml.load(open(lspc_path), Loader=yaml.FullLoader)
+            lspc_dict = util.read_config_file(lspc_path, quiet=True)
             return lspc_dict
 
         # Then look in the same folder where the species database is
         lspc_path = os.path.join(self.spcdb_dir, "lumped_species.yml")
         if os.path.exists(lspc_path):
-            lspc_dict = yaml.load(open(lspc_path), Loader=yaml.FullLoader)
+            lspc_dict = util.read_config_file(lspc_path, quiet=True)
             return lspc_dict
 
         # Then look in the GCPy source code folder
@@ -151,26 +159,16 @@ class _GlobVars:
         Returns the restart file path
 
         Arguments:
-            ystr : Year string (YYYY format
+            ystr : Year string (YYYY) format
         """
-        # Restarts
-        if self.is_gchp:
-            RstPath = os.path.join(
-                self.devrstdir,
-                "gcchem_internal_checkpoint.restart.{}{}".format(
-                    ystr,
-                    "0101_000000.nc4"
-                )
-            )
-        else:
-            RstPath = os.path.join(
-                self.devrstdir,
-                "GEOSChem.Restart.{}0101_0000z.nc4".format(
-                    ystr
-                )
-            )
-
-        return RstPath
+        return util.get_filepath(
+            self.devrstdir,
+            "Restart",
+            np.datetime64(f"{ystr}-01-01T00:00:00"),
+            is_gchp=self.is_gchp,
+            gchp_res=self.gchp_res,
+            gchp_is_pre_14_0=self.gchp_is_pre_14_0
+        )
 
 
     def get_diag_paths(self):
@@ -192,7 +190,7 @@ class _GlobVars:
         for c in collections:
             self.pathlist[c] = os.path.join(
                 self.devdir,
-                "*.{}.{}*.nc4".format(c, self.y0_str)
+                f"*.{c}.{self.y0_str}*.nc4"
             )
 
 
@@ -206,9 +204,8 @@ class _GlobVars:
         Returns:
            ds : xarray Dataset
         """
-        path = self.rst_file_path(ystr)
         ds = xr.open_dataset(
-            path,
+            self.rst_file_path(ystr),
             drop_variables=constants.skip_these_vars
         )
 
@@ -270,7 +267,7 @@ class _GlobVars:
             area_m2 = self.ds_met["Met_AREAM2"].isel(time=0)
             area_m2 = util.reshape_MAPL_CS(area_m2)
             self.area_m2 = area_m2
-            self.area_cm2 = self.ds_met["Met_AREAM2"] * 1.0e4
+            self.area_cm2 = self.ds_met["Met_AREAM2"].isel(time=0) * 1.0e4
         else:
             self.area_m2 = self.ds_met["AREA"].isel(time=0)
             self.area_cm2 = self.area_m2 * 1.0e4
@@ -314,7 +311,7 @@ class _GlobVars:
         """
         # Read the species database
         path = os.path.join(spcdb_dir, "species_database.yml")
-        spcdb = yaml_load_file(open(path))
+        spcdb = util.read_config_file(path, quiet=True)
 
         # Molecular weights [kg mol-1], as taken from the species database
         self.mw = {}
@@ -362,7 +359,7 @@ def init_and_final_mass(
     g100 = 100.0 / constants.G
     airmass_ini = (deltap_ini * globvars.area_m2.values) * g100
     airmass_end = (deltap_end * globvars.area_m2.values) * g100
-
+    
     # Conversion factors
     mw_ratio = globvars.mw["O3"] / globvars.mw["Air"]
     kg_to_tg = 1.0e-9
@@ -466,11 +463,11 @@ def annual_average_drydep(
     mw_avo = (globvars.mw["Ox"] / constants.AVOGADRO)
     kg_to_tg = 1.0e-9
     area_cm2 = globvars.area_cm2.values
-
-    # Get P(Ox) AND L(Ox) [kg/s]
+    
+    # Get drydep flux of Ox [molec/cm2/s]
     dry = globvars.ds_dry["DryDep_Ox"].values
 
-    # Monthly-weighted conv & LS wet losses [kg HNO3/s]
+    # Convert to Tg Ox 
     dry_tot = 0.0
     for t in range(globvars.N_MONTHS):
         dry_tot += np.nansum(dry[t, :, :] * area_cm2) * globvars.frac_of_a[t]
@@ -604,10 +601,9 @@ def print_budget(
     with open(filename, "w+") as f:
         print("="*50, file=f)
         print("Annual Average Global Ox Budget", file=f)
-        print("for GEOS-Chem {} 1-year benchmark\n".format(
-            globvars.devstr), file=f)
-        print("Start: {}-01-01 00:00 UTC".format(globvars.y0_str), file=f)
-        print("End:   {}-01-01 00:00 UTC".format(globvars.y1_str), file=f)
+        print(f"for GEOS-Chem {globvars.devstr} 1-year benchmark\n", file=f)
+        print(f"Start: {globvars.y0_str}-01-01 00:00 UTC", file=f)
+        print(f"End:   {globvars.y1_str}-01-01 00:00 UTC", file=f)
         print("="*50, file=f)
         print("\n", file=f)
         print("  MASS ACCUMULATION       Tg Ox a-1    Tg O3 a-1", file=f)
@@ -664,12 +660,14 @@ def global_ox_budget(
         devrstdir,
         year,
         dst='./1yr_benchmark',
-        is_gchp=False,
         overwrite=True,
-        spcdb_dir=None
+        spcdb_dir=None,
+        is_gchp=False,
+        gchp_res="c24",
+        gchp_is_pre_14_0=False
 ):
     """
-    Main program to compute TransportTracersBenchmark budgets
+    Main program to compute Ox budgets
 
     Arguments:
         maindir: str
@@ -683,15 +681,22 @@ def global_ox_budget(
         dst: str
             Directory where budget tables will be created.
             Default value: './1yr_benchmark'
-        is_gchp: bool
-            Denotes if data is from GCHP (True) or GCC (false).
-            Default value: False
         overwrite: bool
             Denotes whether to ovewrite existing budget tables.
             Default value: True
         spcdb_dir: str
             Directory where species_database.yml is stored.
             Default value: GCPy directory
+        is_gchp: bool
+            Denotes if data is from GCHP (True) or GCC (false).
+            Default value: False
+        gchp_res: str
+            GCHP resolution string (e.g. "c24", "c48", etc.)
+            Default value: None
+        gchp_is_pre_14_0: bool
+            Denotes if the version is prior to GCHP 14.0.0 (True)
+            or not (False).
+            Default value: False
     """
 
     # Store global variables in a private class
@@ -701,9 +706,11 @@ def global_ox_budget(
         devrstdir,
         year,
         dst,
-        is_gchp,
         overwrite,
-        spcdb_dir
+        spcdb_dir,
+        is_gchp,
+        gchp_res,
+        gchp_is_pre_14_0,
     )
 
     # ==================================================================
@@ -747,3 +754,14 @@ def global_ox_budget(
         drydep,
         metrics
     )
+
+    # ==================================================================
+    # Force garbage collection
+    # ==================================================================
+    del globvars
+    del mass
+    del prodloss
+    del wetdep
+    del drydep
+    del metrics
+    gc.collect()
